local array = include( "modules/array" )
local util = include( "modules/util" )
local cdefs = include( "client_defs" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local unitdefs = include("sim/unitdefs")
local simfactory = include( "sim/simfactory" )
local inventory = include("sim/inventory")
local abilityutil = include( "sim/abilities/abilityutil" )


return {
	name = STRINGS.URIST.PRIME_ATOMSMASHER,

	getName = function( self, sim, unit )
		return self.name
	end,

	createToolTip = function( self, sim, unit )
		return abilityutil.formatToolTip(STRINGS.URIST.PRIME_ATOMSMASHER, STRINGS.URIST.PRIME_ATOMSMASHER_DESC, simdefs.DEFAULT_COST)
	end,

	alwaysShow = true,

	profile_icon = "gui/icons/action_icons/Action_icon_Small/icon-item_hijack_small.png",


	canUseAbility = function( self, sim, abilityOwner, abilityUser )

		if abilityOwner == abilityUser then
			return false
		end

		if not abilityUser then
			return false
		end

		if abilityOwner:getTraits().cooldown and abilityOwner:getTraits().cooldown > 0 then
			return false, util.sformat(STRINGS.UI.REASON.COOLDOWN,abilityOwner:getTraits().cooldown)
		end

		if abilityOwner:getTraits().usesCharges and abilityOwner:getTraits().charges < 1 then
			return false, util.sformat(STRINGS.UI.REASON.CHARGES)
		end				

		if array.find( abilityUser:getChildren(), abilityOwner ) == nil then
			return false, STRINGS.UI.REASON.NOT_CARRIED
		end

		return abilityutil.checkRequirements( abilityOwner, abilityUser )
	end,
	
	executeAbility = function( self, sim, abilityOwner, abilityUser )
		local cell = sim:getCell( abilityUser:getLocation() )

		abilityUser:removeChild( abilityOwner )

		abilityOwner:setPlayerOwner( abilityUser:getPlayerOwner() )

		sim:emitSound( simdefs.SOUND_ITEM_PUTDOWN, cell.x, cell.y, abilityUser )
		sim:emitSound( simdefs.SOUND_PRIME_EMP, cell.x, cell.y, abilityUser )
		sim:dispatchEvent( simdefs.EV_UNIT_PICKUP, { unitID = abilityUser:getID() } )	

		sim:warpUnit( abilityOwner, cell )
		sim:dispatchEvent( simdefs.EV_UNIT_DEPLOY, { unit = abilityOwner, x = cell.x, y = cell.y } )

		abilityOwner:removeAbility( sim, "carryable" )

		if abilityOwner:getTraits().mainframe_status then
			abilityOwner:getTraits().mainframe_item = true
			abilityOwner:getTraits().mainframe_status = "on"
		end

		sim:triggerEvent( simdefs.TRG_UNIT_DEPLOYED, { unit = abilityOwner } )
		sim:dispatchEvent( simdefs.EV_UNIT_REFRESH, { unit = abilityOwner } )
	end,
}