local array = include( "modules/array" )
local util = include( "modules/util" )
local simdefs = include("sim/simdefs")
local simquery = include("sim/simquery")
local simfactory = include("sim/simfactory")
local unitdefs = include("sim/unitdefs")
local abilityutil = include( "sim/abilities/abilityutil" )

return {
	name = STRINGS.URIST.SOCKDROPPER,

	getName = function( self, sim, abilityOwner, abilityUser )
		return self.name
	end,

	onSpawnAbility = function( self, sim, unit )
        self.abilityOwner = unit
        -- sim:addTrigger( simdefs.TRG_DEL_INTEREST, self )
        sim:addTrigger( "MarkInterestInvestigated_urist", self )
        sim:addTrigger( simdefs.TRG_START_TURN, self )
        sim:addTrigger( simdefs.TRG_END_TURN, self )
	end,

	onDespawnAbility = function( self, sim, unit )
        -- sim:removeTrigger( simdefs.TRG_DEL_INTEREST, self )
        sim:removeTrigger( "MarkInterestInvestigated_urist", self )
        sim:removeTrigger( simdefs.TRG_START_TURN, self )
        sim:removeTrigger( simdefs.TRG_END_TURN, self )
        self.abilityOwner = nil
		if self.sock then
			sim:warpUnit( self.sock, nil )
			sim:despawnUnit( self.sock )
			self.sock = nil
		end
	end,

    onTrigger = function( self, sim, evType, evData )
		-- before trigger-specific handlers, validate the state
		if self.sock and not self.sock:isValid() then
			self.sock = nil
			self.destroyedInTurns = nil
		end

        -- if evType == simdefs.TRG_DEL_INTEREST then
        if evType == "MarkInterestInvestigated_urist" then
			if evData.unit and evData.unit:isValid() and self.sock and simquery.isSameLocation( evData.unit, self.sock ) then
				self:destroySock( sim )
				evData.unit:setTagged()
			end
        elseif evType == simdefs.TRG_END_TURN then
			if evData:isNPC() and self.sock then
				self.destroyedInTurns = (self.destroyedInTurns or self.sock:getTraits().destroyedInTurns or 5) - 1
				self.sock:getTraits().destroyedInTurns = self.destroyedInTurns
				if self.destroyedInTurns < 1 then
					self:destroySock( sim )
				else
					local unitID = self.sock:getID()
					local player = self.sock:getPlayerOwner()
					player:glimpseUnit( sim, unitID )
				end
			end
        elseif evType == simdefs.TRG_START_TURN then
			if evData:isPC() and sim:getTurnCount() > 0 and not self.sock and not self.abilityOwner:isDown() then
				-- get a list of available guards
				local guards = {}
				for _, unit in pairs( sim:getNPC():getUnits() ) do
					if unit and unit:canAct() and unit:getBrain() and not unit:isAiming() and not unit:getTraits().noInterestDistraction then
						table.insert( guards, unit )
					end
				end
				-- only spawn a sock if there's somebody to investigate it
				if #guards > 0 then
					local x0, y0 = self.abilityOwner:getLocation()
					local player = self.abilityOwner:getPlayerOwner()
					-- create sock
					self.sock = simfactory.createUnit( unitdefs.lookupTemplate( "sock_urist" ), sim )
					sim:spawnUnit( self.sock )
					self.sock:setPlayerOwner( player )
					self.destroyedInTurns = 5
					self.sock:getTraits().destroyedInTurns = self.destroyedInTurns
					sim:warpUnit( self.sock, sim:getCell( x0, y0 ) )
					-- fx
					sim:dispatchEvent( simdefs.EV_UNIT_FLOAT_TXT, { unit = self.abilityOwner , txt=STRINGS.URIST.SOCKDROPPER, x=x0,y=y0,color={r=178/255,g=255/255,b=255/255,a=1}  } )
					-- sus random guard
					local guard = guards[ sim:nextRand( #guards ) ]
					-- REASON_SCANNED prevents grenade throws
					guard:getBrain():spawnInterest(x0, y0, simdefs.SENSE_RADIO, simdefs.REASON_SCANNED, self.sock)
					player:glimpseUnit( sim, guard:getID() )
				end
			end
        end
    end,
	
	destroySock = function( self, sim )
		local unitID = self.sock:getID()
		local player = self.sock:getPlayerOwner()
		sim:warpUnit( self.sock, nil )
		sim:despawnUnit( self.sock )
		player:glimpseUnit( sim, unitID )
		self.sock = nil
		self.destroyedInTurns = nil
	end,
}