-- NOTES:
-- All dwarves in Dwarf Fortress have a personality
-- comprised of spectra (1 dimension each), grouped as
-- beliefs (=respect and ideals) and facets (=habits).
-- Each position on each belief spectrum has a quote,
-- which are particularly interesting banter-material.
-- Extreme facets also have quotes, though situational.
-- 
-- IDEAS:
-- "It is best not to complicate your life with lies."
-- banks lockpicking vs urist breaching
-- maria air scout vs urist urban scout

return function(modApi)
	local DECKER = 1
	local SHALEM = 2
	local XU = 3
	local BANKS = 4
	local NIKA = 6
	local MARIA = 5
	local SHARP = 7
	local PRISM = 8
	local MONSTER = 100
	local CENTRAL = 108
	local OLIVIA = 1000
	local DEREK = 1001
	local RUSH = 1002
	local DRACO = 1003
	local PEDLER = "mod_01_pedler"
	local MIST = "mod_02_mist"
	local GHUFF = "mod_03_ghuff"
	local NUMI = "mod_04_n_umi"
	local DOSAN = "dosan_01"
	local CONWAY = "gunpoint_conway"
	local RED = "transistor_red"
	local SOMBRA = "SOMBRA_001"
	local WIDOWMAKER = "WIDOWMAKER_001"
	local CARMEN = "carmen_sandiego_o"
	local AGENT47 = "agent_47_o"
	local GOOSE = "mod_goose"
	local TOOSE = "mod_goose_2"
	local URIST = "urist"
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, DECKER},
			dialogue = {
				{URIST, "I'll buy you a beer after this." },
				{DECKER, "It's always beer with you." }, -- dwarves actually drink wine and even spirits too
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, MARIA},
			dialogue = {
				{MARIA, "Exactly how dangerous is your transport pad?" },
				{URIST, "Depends on the fall height. But time heals all wounds." },
				{MARIA, "If the freshly unemployable guard could afford time without income, yes." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, SHALEM},
			dialogue = {
				{URIST, "When all other bonds wither, friendship will remain." }, -- friendship respect
				{SHALEM, "How did that work out for you?" },
				{URIST, "My trust is earned, and not by many." }, -- trust facet
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, MARIA},
			dialogue = {
				{URIST, "I made a friend like you in Cuba." },
				{MARIA, "Like me? ...Had you deployed for the re-annexation?" }, -- annexation was no later than 2063, several years too early for Urist
				{URIST, "Afterwards, peacekeeping. It was the wrong time for their sacrifice and I told them so. They escaped." }, -- dwarves are usually ambivalent on sacrifice unless trauma changed their views
				{MARIA, "I see. Thank you." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, XU},
			dialogue = {
				{URIST, "I do admire a clever trap. Give me the bustle and noise over all that quiet!" }, -- cunning respect and tranquility respect
				{XU, "If it results in bustle and noise, it is arguably not a clever trap." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, PRISM},
			dialogue = {
				{PRISM, "How come your hair isn't black? Fashion statement?" },
				{URIST, "I can see a place for maintaining decorum, but it's exhausting to live that way." }, -- decorum respect
				-- cleverly dodging the question of whether black is naturally prevalent among males or merely a social standard
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, SHARP},
			dialogue = {
				{URIST, "A skilled warrior is a beautiful sight to behold." }, -- martial art respect
				{SHARP, "I am, and you shall observe as I prove my supremacy once more." },
				{URIST, "Show some mercy now and again." }, -- cruelty facet
				{SHARP, "Make up your mind." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, OLIVIA},
			dialogue = {
				{OLIVIA, "I will let you know if and where to breach into vaults." }, -- "vaults" exist in DF, but are too obscure to reference
				{URIST, "Alright, but I don't breach without knowing the other side. Not since the circus clowns." }, -- euphemism for unleashing demons of the underworld cavern layer
				{OLIVIA, "Circus? You know what, nevermind. I'll chalk it up to structural obstacles." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, CENTRAL},
			dialogue = {
				{CENTRAL, "Perhaps it is time that you tell me what the circus indicent was." }, -- euphemism for the underworld cavern layer
				{URIST, "I had a greedy streak and though I believed to know the lay of the land, I tumbled straight into the underworld." }, -- "greedy streak" is default for dwarves
				{CENTRAL, "Given your aversion to speculative breaching, you literally burst into a crime organisation?" },
				{URIST, "No, the clowns were all but organised. Chaos reigned." }, -- euphemism for demons; "chaos" is a common divine sphere emitted by demons
				-- {URIST, "...Vortices of purple light... Bottomless glowing pits... Horrifying screams... So easily broken..." }, -- various ingame descriptions, and common thought to injury
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, MONSTER},
			dialogue = {
				{URIST, "Eurgh, nausea. Transport beams..." },
				{MONSTER, "It might be caused by resonance with your equipment. I'd know." },
				--TODO this is not a satisfying banter yet
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, BANKS},
			dialogue = {
				{BANKS, "Are your breadcrumbs ready?" },
				{URIST, "We are not Hansel and Gretel." },
				{BANKS, "But you like to chew through the walls." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, NIKA},
			dialogue = {
				{URIST, "You are always loyal to your cause and the ones you serve. I admire that." }, -- loyalty respect
				{NIKA, "Because you are not?" },
				{URIST, "I try to repay loyalty in full, but death is all around us. I abandoned no one for Invisible." }, -- loyalty respect and common thought to corpses
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, SHALEM},
			dialogue = {
				{SHALEM, "You boast your beliefs so freely. Did you never get into trouble for it?" },
				{URIST, "Don't bother trying to play on my emotions." }, -- literally what NPCs say in adventure mode when flattery fails
				--TODO should Urist throw back a snarky remark?
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, DECKER},
			dialogue = {
				{DECKER, "Why did Central bring you here?" },
				{URIST, "I excel at carving paths, when covered by capable colleagues such as yourself." }, -- hihi "carving" get it?
				{DECKER, "No, I mean Invisible as a whole. You're not here for revenge or escape." },
				{URIST, "As said, I prefer my job with reliable associates. Military is deliberately impersonal." }, -- most dwarves greatly value family and friendship
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, NIKA},
			dialogue = {
				-- attracting guards (noise/sock)
				{URIST, "I don't mind stirring things up. Do you?" }, -- discord facet
				{NIKA, "Poprobuy. I'm ready." }, --TODO help native russian speaker direly needed
				-- {URIST, "There's nothing like a good brawl." }, -- violent facet
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, PRISM},
			dialogue = {
				{PRISM, "Nice gas mask." },
				{URIST, "It is a respirator, strictly speaking. It is not airtight over my beard, anyways." },
				{PRISM, "Ah yes, style versus survival. A grave conundrum." },
				{PRISM, "...Hypothetically, if there is poison gas, you'd let me have the mask, OK?" },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, BANKS},
			dialogue = {
				{URIST, "Wouldn't it be grand to just take my life off and do nothing for the rest of my days?" }, -- leisure respect
				{BANKS, "You'd probably get bored and go back to help people you like." },
				{URIST, "So true! But I'd rather we all get a chance to be merry together." }, -- "so true" is a response when agreeing with a belief statement, merriment respect
				--TODO needs some sort of punchline
			},
		} )
	
	-- By: Mobbstar;
	-- modApi:addBanter( {
			-- agents = {URIST, SHARP},
			-- dialogue = {
				-- {SHARP, "If you wind up getting yourself surrounded, don't count on me to drag your blood-leaking filth out." }, -- particularly relevant to onfile urist, being the only agent to gameplay-involuntarily attract guards
				-- {URIST, "Sometimes you just have to know when it's time to stop." }, -- sacrifice respect
				-- {SHARP, "" },
			-- },
		-- } )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, MONSTER},
			dialogue = {
				{URIST, "Trade is the life-blood of a thriving society." },
				{MONSTER, "Then I suppose that makes me the heart." },
				{URIST, "If you believe society is thriving thanks to your business." }, -- This might be uncharacteristically confrontational, but Urist seeks out discord as evidenced by the other banters.
				{MONSTER, "Secret societies certainly are. Let me know if you'd rather not receive offers anymore." },
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, XU},
			dialogue = {
				{URIST, "All of that so-called knowledge doesn't mean a thing." }, -- knowledge respect
				{XU, "As a matter of fact, knowledge IS the meaning of things. But I won't get into this now." },
				{URIST, "Later then. We grow through debate and struggle, even chaos and discord." }, -- harmony respect
			},
		} )
	
	-- By: Mobbstar;
	modApi:addBanter( {
			agents = {URIST, SHALEM},
			dialogue = {
				{URIST, "Have you ever been on the receiving end of a snipe?" },
				{SHALEM, "My head is still whole, so... No, obviously not." },
				{URIST, "I have. I would be dead, had my beard not stopped the bullet." },
				{SHALEM, "I'm looking forward to seeing you repeat that miracle if necessary." },
			},
		} )
	
end
