-- Include files to be used throughout this file.
-- Don't eager-load sim- or client-heavy things though, those may break translation.
-- local util = include( "modules/util" )

-- Private static variables can be used by load/unload to remember what has been done.
local ThisModLoaded = false

local function earlyInit( modApi )
    -- List all mods that must load before this one, using their modinfo.txt names.
    modApi.requirements = { "Contingency Plan", "Sim Constructor", "Function Library", "Mods Combo by Shirsh" }
end

-- Init runs only once, when the game boots up.
local function init( modApi )

    -- Load all kwads here.
    local dataPath = modApi:getDataPath()
    KLEIResourceMgr.MountPackage( dataPath .. "/gui.kwad", "data" )
    KLEIResourceMgr.MountPackage( dataPath .. "/sound.kwad", "data" )
    MOAIFmodDesigner.loadFEV("urist.fev")
    KLEIResourceMgr.MountPackage( dataPath .. "/anims.kwad", "data" )

    -- Declare all campaign settings here.
    modApi:addGenerationOption("onfile_urist",  STRINGS.URIST.OPTIONS.URIST_ONFILE, STRINGS.URIST.OPTIONS.URIST_ONFILE_TIP, {noUpdate = true})
    modApi:addGenerationOption("archive_urist",  STRINGS.URIST.OPTIONS.URIST_ARCHIVE, STRINGS.URIST.OPTIONS.URIST_ARCHIVE_TIP, {noUpdate = true} )
    
    
    local scriptPath = modApi:getScriptPath()
    -- dear teleport_units gfx
    -- why do you make me do these things
    local upvaluehacker = include( scriptPath .. "/upvaluehacker" )
    local itemrig = include( "gameplay/itemrig" )
    local itemtex_rig = upvaluehacker.GetUpvalue( itemrig.createRig, "itemtex_rig" )
    -- setHidden, like in unitrig
    itemtex_rig.setHidden = function( self, isHidden )
        if isHidden ~= self._isHidden then
            self._isHidden = isHidden
            self:refreshLocation()
        end
    end
    local refreshLocation = itemtex_rig.refreshLocation
    itemtex_rig.refreshLocation = function( self )
        refreshLocation( self )
        -- repeat the last bit to update isVisible
        if self._isHidden and self._isVisible then
            self._boardRig:getLayer("floor"):removeProp( self._prop )
            self._isVisible = false
        end
    end

    -- May as well commit more crimes, for convenience. :)
    local Actions = include( "sim/btree/actions" )
    local MarkInterestInvestigated = Actions.MarkInterestInvestigated
    Actions.MarkInterestInvestigated = function( sim, unit, ... )
        sim:triggerEvent( "MarkInterestInvestigated_urist", {unit=unit} )
        return MarkInterestInvestigated( sim, unit, ... )
    end

    -- wallbreacher stuff

    local function stopBreaching( sim, abilityUser )
        local abilityOwner = sim:getUnit( abilityUser:getTraits().data_hacking )
        assert( abilityOwner, abilityUser:getName() )
        local ability = abilityOwner:hasAbility( "wallbreacher" )
        assert( ability, abilityOwner:getName() )
        ability:stopUsingAbility( sim, abilityOwner, abilityUser )
    end

    local simunit = include( "sim/simunit" )
    local progressHack = simunit.progressHack
    simunit.progressHack = function( self, ... )
        if not self:getTraits().wallbreacher then
            return progressHack( self, ... )
        end
    end
    local stopHacking = simunit.stopHacking
    simunit.stopHacking = function( self, sim, ... )
        if self:getTraits().wallbreacher then
            stopBreaching( sim, self )
        else
            return stopHacking( self, sim, ... )
        end
    end

    local simengine = include( "sim/engine" )
    local moveUnit = simengine.moveUnit
    simengine.moveUnit = function( self, unit, ... )
        if unit:getTraits().wallbreacher then
            stopBreaching( self, unit )
        end
        return moveUnit( self, unit, ... )
    end

end


local function FindModOption( mod_options, modname, optionname )
    if not mod_options then return end
    for k, v in pairs( mod_options ) do
        if k == modname or v.name == modname then
            if v.enabled and v.options and v.options[optionname] then
                return v.options[optionname].value or v.options[optionname].enabled
            end
            return -- can give up at this point
        end
    end
end


-- Load runs every time a campaign gets started or resumed.
local function load( modApi, options, params, mod_options )
    ThisModLoaded = true

    local scriptPath = modApi:getScriptPath()

    modApi:addTooltipDef( include( scriptPath .. "/tooltipdefs" ) )

    local animdefs = include( scriptPath .. "/animdefs" )
    if FindModOption( mod_options, "Mods Combo by Shirsh", "noWireframes" ) then
        animdefs = include( scriptPath .. "/animdefs_no_wireframes" )
    end
    for name, animDef in pairs(animdefs) do
        modApi:addAnimDef( name, animDef )
    end

    local mod_itemdefs = include( scriptPath .. "/itemdefs" )
    local mod_propdefs = include( scriptPath .. "/propdefs" )

    modApi:addItemDef( "augment_sockdropper", mod_itemdefs.augment_sockdropper )
    modApi:addPropDef( "sock_urist", mod_propdefs.sock_urist, false )
    modApi:addAbilityDef( "sockdropper", scriptPath .. "/abilities/sockdropper" )

    modApi:addItemDef( "item_atomsmasher", mod_itemdefs.item_atomsmasher )
    modApi:addAbilityDef( "prime_atomsmasher", scriptPath .. "/abilities/prime_atomsmasher" )
    modApi:addAbilityDef( "pickup_atomsmasher", scriptPath .. "/abilities/pickup_atomsmasher" )
    include( scriptPath .. "/units/simatomsmasher" )

    modApi:addItemDef( "augment_wallbreacher", mod_itemdefs.augment_wallbreacher )
    modApi:addAbilityDef( "wallbreacher", scriptPath .. "/abilities/wallbreacher" )

    local mod_agentdefs = include( scriptPath .. "/agentdefs" )
    modApi:addAgentDef( "urist", mod_agentdefs.urist , { "urist", "urist_a" } )
    modApi:addAgentDef( "urist_a", mod_agentdefs.urist_a )

    local onfile_enabled = options["onfile_urist"] and options["onfile_urist"].enabled
    local archive_enabled = options["archive_urist"] and options["archive_urist"].enabled
    
    local serverdefs = include( "modules/serverdefs" )
    if onfile_enabled and (not archive_enabled or math.random() < .5) then
        modApi:addRescueAgent( serverdefs.createAgent( "urist", {"augment_sockdropper"} ) )
    elseif archive_enabled then
        modApi:addRescueAgent( serverdefs.createAgent( "urist_a", {"augment_wallbreacher"} ) )
    end

    include( scriptPath .. "/banter" )( modApi )
end

-- Unload runs every time a campaign gets quit.
local function unload( modApi, options )
    ThisModLoaded = false
end

-- This function runs as soon as the game boots, before init, and should only be used to set translatable text.
local function initStrings(modApi)
    local dataPath = modApi:getDataPath()
    local scriptPath = modApi:getScriptPath()
    local strings = include(scriptPath .. "/strings" )
    modApi:addStrings( dataPath, "URIST", strings)
end

return {
    init = init,
    earlyInit = earlyInit,
    load = load,
    unload = unload,
    initStrings = initStrings,
}