local util = include( "modules/util" )
local array = include( "modules/array" )
local simunit = include( "sim/simunit" )
local simdefs = include( "sim/simdefs" )
local simquery = include( "sim/simquery" )
local simfactory = include( "sim/simfactory" )
local inventory = include( "sim/inventory" )
local mainframe = include( "sim/mainframe" )

local _M = { ClassType = "simatomsmasher" }

function _M:toggle( sim )
	local x0,y0 = self:getLocation()
	local player = self:getPlayerOwner()
	local cell = sim:getCell( x0, y0 )

	sim:getPC():addCPUs(- self:getTraits().PWRuse)

	-- have to exclude self for gfx
	local targets = {}
	for i, cellUnit in ipairs( cell.units ) do
		if cellUnit ~= self then
			table.insert( targets, cellUnit )
		end
	end

	-- sim:dispatchEvent( simdefs.EV_FLASH_VIZ, {x = x0, y = y0, units = nil, range = 1} )
	sim:dispatchEvent( simdefs.EV_TELEPORT, { units = targets, warpOut = true } )

	local survivors = {}
	for i, cellUnit in ipairs( targets ) do
		-- Tagged units are probably important. (e.g. Monst3r and Central in story missions)
		-- See also: simunit.hasTag
		if (cellUnit._tags and next(cellUnit._tags))
		or (cellUnit:getUnitData().tags and next(cellUnit:getUnitData().tags)) then
			-- find random viable cell
			-- TODO could probably optimise this by caching the cells until end of process
			local allCells = {}
			sim:forEachCell(function(_cell)
				local cell = _cell
				if (cell.impass == nil or cell.impass <= 0) and not cell.isSolid then
					table.insert(allCells,cell)
				end
			end)
			if #allCells > 0 then
				local spawncell = allCells[ sim:nextRand( #allCells ) ]
				sim:warpUnit( cellUnit, spawncell )
			end
			table.insert( survivors, cellUnit )
		elseif cellUnit:isValid() then
			-- Stay consistent with kill mechanics in this regard
			-- Enforcers return
			if cellUnit:getTraits().enforcer then 
				sim:addEnforcersToSpawn( 1 )
			end
			-- Ongoing programs reset
			if cellUnit:getTraits().parasite then
				mainframe.removeParasite(sim:getPC(),cellUnit)
			end
			-- Cyberconscious go away too
			if cellUnit:getTraits().mainframe_device then
				local mainFrameDevice = sim:getUnit(cellUnit:getTraits().mainframe_device)
				mainFrameDevice:getTraits().mainframe_program = nil
				mainFrameDevice:getTraits().daemonHost = nil
			end
			-- Agents go MIA correctly.
			sim:warpUnit( cellUnit, nil )
			sim:despawnUnit( cellUnit )
		end
	end

	if #survivors > 0 then
		-- or reveal them one-by-one? would allow for better panning and reaction processing
		-- TODO should also check if they're still valid
		sim:dispatchEvent( simdefs.EV_TELEPORT, { units = survivors, warpOut = false } )
		local x1, y1 = survivors[1]:getLocation()
		sim:dispatchEvent( simdefs.EV_CAM_PAN, { x1, y1 } )
	end

	-- sim:emitSound( simdefs.SOUND_SMALL, x0, y0, nil )
	sim:processReactions( self )

	inventory.useItem( sim, self, self )
end

-----------------------------------------------------

local function createAtomsmasher( unitData, sim )
	return simunit.createUnit( unitData, sim, _M )
end

simfactory.register( createAtomsmasher )

return
{
	createAtomsmasher = createAtomsmasher,
}
